@@ -556,7 +556,7 @@ print "\n\n\n\n\n\n\nSTDERR=$stderr\n\n\n\n\n\n\n";
          } elsif (!$second_pass) {
             $handle->{_cmd_handle}->print(
                'GRANT USAGE ON gnusocial.* TO gnusocial@localhost'.
-               ' IDENTIFIED BY \'$service_and_cert_password\';');
+               " IDENTIFIED BY \'$service_and_cert_password\';");
             $second_pass=1;
          } elsif (!$third_pass) {
             $handle->{_cmd_handle}->print(
@@ -742,7 +742,7 @@ END
          'dbtype' => 'mysql',
          'database' => 'gnusocial',
          'dbusername' => 'gnusocial',
-         'dbpassword' => 'goodrandompassword',
+         'dbpassword' => $service_and_cert_password,
          'admin_nickname' => 'admin',
          'admin_password' => 'admin',
          'admin_password2' => 'admin',
